# Section 3

## source

![source](cell.ipynb){#fig:source .source}

## cell

![cell](cell.ipynb){#fig:source .cell}

## png

![png](cell.ipynb){#fig:cell-png .cell width=2cm}

## stdout

![stdout](cell.ipynb){#text:stdout .cell}

## print

![print](cell.ipynb){#text:print .cell}

## both

![print](cell.ipynb){#text:both .cell}

## pandas/text

![pandas](cell.ipynb){#text:pandas .cell}

## polars/text

![polars](cell.ipynb){#text:polars .output}

## pandas/html

![pandas](cell.ipynb){#text:pandas .cell .html}

## polars/html

![polars](cell.ipynb){#text:polars .output .html}

## snippet

![snippet](a.txt){.source .output title=hello.txt}
